#include "svg.h"

void
svg_begin(double width, double height) {
    std::cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    std::cout << "<svg ";
    std::cout << "width='" << width << "' ";
    std::cout << "height='" << height << "' ";
    std::cout << "viewBox='0 0 " << width << " " << height << "' ";
    std::cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
svg_text(double left, double baseline, std::string text) {
    std::cout << "<text x='"<< left <<"' y='"<< baseline <<"'>"<< text <<"</text>";
}

void svg_rect(double x, double y, double width, double height, std::string fill_opacity, std::string stroke = "black", std::string fil = "black"){
    std::cout<< "<rect x='"<< x <<"' y='"<< y <<"' width='"<< width <<"' height='"<< height <<"' fill-opacity='"<< fill_opacity<<"' />";
}

void
show_histogram_svg(std::vector<size_t>& bins, size_t & max_count,size_t & bin_count) {
    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 300;
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BLOCK_WIDTH = (IMAGE_WIDTH - TEXT_WIDTH)/max_count;

    svg_begin(IMAGE_WIDTH, IMAGE_HEIGHT);

    double top = 0;
    for (size_t bin : bins) {
        const double bin_width = BLOCK_WIDTH * bin;
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, std::to_string(bin));
        double fill_opacity=double(bin) / max_count;
        svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, std::to_string(fill_opacity));
        top += BIN_HEIGHT;
    }
    svg_end();
}

void
svg_end() {
    std::cout << "</svg>\n";
}
